Module credential_source

Module credential_source 

Structs

ExtractedToken
A token extracted from a specific source.

Enums

CredentialSource
Source from which a token can be extracted.

Functions

extract_token_from_cookie
Extract a token from a named cookie in the Cookie header.
extract_token_from_header
Extract a bearer token from the Authorization header.
extract_token_from_query
Extract a token from the query string of a URI.
extract_token_multi
Try each source in order, returning the first successful extraction.
redact_query_params
Replace sensitive query parameter values with [REDACTED].