Structs
- Extracted
Token - A token extracted from a specific source.
Enums
- Credential
Source - Source from which a token can be extracted.
Functions
- extract_
token_ from_ cookie - Extract a token from a named cookie in the
Cookieheader. - extract_
token_ from_ header - Extract a bearer token from the
Authorizationheader. - extract_
token_ from_ query - Extract a token from the query string of a URI.
- extract_
token_ multi - Try each source in order, returning the first successful extraction.
- redact_
query_ params - Replace sensitive query parameter values with
[REDACTED].